@@ -24,8 +24,10 @@
 
 
 #include <KAboutData>
+#include <KCrash>
 #include <QApplication>
 #include <KLocalizedString>
+#include <KDBusService>
 #include <QCommandLineParser>
 #include <kdelibs4configmigrator.h>
 
@@ -47,6 +49,7 @@ int main(int argc, char *argv[])
     KAboutData aboutData( "kjumpingcube", i18n("KJumpingCube"),
                           KJC_VERSION, i18n(description), KAboutLicense::GPL,
                           i18n("(c) 1998-2000, Matthias Kiefer"));
+    aboutData.setOrganizationDomain(QByteArray("kde.org"));
     aboutData.addAuthor(i18n("Matthias Kiefer"),QString(), "matthias.kiefer@gmx.de");
     aboutData.addAuthor(i18n("Benjamin Meyer"),i18n("Various improvements"), "ben+kjumpingcube@meyerhome.net");
     aboutData.addCredit(i18n("Ian Wadham"),
@@ -59,11 +62,13 @@ int main(int argc, char *argv[])
 
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
+    KCrash::initialize();
     parser.addVersionOption();
     parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
+    KDBusService service;
 
     app.setWindowIcon(QIcon::fromTheme(QLatin1String("kjumpingcube")));
 
@@ -72,8 +77,8 @@ int main(int argc, char *argv[])
         RESTORE(KJumpingCube)
     }
     else {
-		KJumpingCube *kjumpingcube = new KJumpingCube;
-		kjumpingcube->show();
-	}
-   return app.exec();
+        KJumpingCube *kjumpingcube = new KJumpingCube;
+        kjumpingcube->show();
+    }
+    return app.exec();
 }
