@@ -15,15 +15,21 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ********************************************************************** */
 
+#ifndef SETTINGSWIDGET_H
+#define SETTINGSWIDGET_H
+
 // Settings widget.
 #include "ui_settings.h"
 
 class SettingsWidget : public QWidget, public Ui::Settings
 {
 public:
-    SettingsWidget(QWidget *parent)
+    explicit SettingsWidget(QWidget *parent)
         : QWidget(parent)
         {
             setupUi(this);
         }
 };
+
+#endif
+
